hipJitOption

Enum hipJitOption 

#[repr(u32)]
pub enum hipJitOption {
Show 32 variants hipJitOptionMaxRegisters = 0, hipJitOptionThreadsPerBlock = 1, hipJitOptionWallTime = 2, hipJitOptionInfoLogBuffer = 3, hipJitOptionInfoLogBufferSizeBytes = 4, hipJitOptionErrorLogBuffer = 5, hipJitOptionErrorLogBufferSizeBytes = 6, hipJitOptionOptimizationLevel = 7, hipJitOptionTargetFromContext = 8, hipJitOptionTarget = 9, hipJitOptionFallbackStrategy = 10, hipJitOptionGenerateDebugInfo = 11, hipJitOptionLogVerbose = 12, hipJitOptionGenerateLineInfo = 13, hipJitOptionCacheMode = 14, hipJitOptionSm3xOpt = 15, hipJitOptionFastCompile = 16, hipJitOptionGlobalSymbolNames = 17, hipJitOptionGlobalSymbolAddresses = 18, hipJitOptionGlobalSymbolCount = 19, hipJitOptionLto = 20, hipJitOptionFtz = 21, hipJitOptionPrecDiv = 22, hipJitOptionPrecSqrt = 23, hipJitOptionFma = 24, hipJitOptionPositionIndependentCode = 25, hipJitOptionMinCTAPerSM = 26, hipJitOptionMaxThreadsPerBlock = 27, hipJitOptionOverrideDirectiveValues = 28, hipJitOptionNumOptions = 29, hipJitOptionIRtoISAOptExt = 10_000, hipJitOptionIRtoISAOptCountExt = 10_001,
}
hipJitOption

Variants



hipJitOptionMaxRegisters = 0

< CUDA Only Maximum registers may be used in a thread, < passed to compiler



hipJitOptionThreadsPerBlock = 1

< CUDA Only Number of thread per block



hipJitOptionWallTime = 2

< CUDA Only Value for total wall clock time



hipJitOptionInfoLogBuffer = 3

< CUDA Only Pointer to the buffer with logged information



hipJitOptionInfoLogBufferSizeBytes = 4

< CUDA Only Size of the buffer in bytes for logged info



hipJitOptionErrorLogBuffer = 5

< CUDA Only Pointer to the buffer with logged error(s)



hipJitOptionErrorLogBufferSizeBytes = 6

< CUDA Only Size of the buffer in bytes for logged < error(s)



hipJitOptionOptimizationLevel = 7

< Value of optimization level for generated codes, acceptable < options -O0, -O1, -O2, -O3



hipJitOptionTargetFromContext = 8

< CUDA Only The target context, which is the default



hipJitOptionTarget = 9

< CUDA Only JIT target



hipJitOptionFallbackStrategy = 10

< CUDA Only Fallback strategy



hipJitOptionGenerateDebugInfo = 11

< CUDA Only Generate debug information



hipJitOptionLogVerbose = 12

< CUDA Only Generate log verbose



hipJitOptionGenerateLineInfo = 13

< CUDA Only Generate line number information



hipJitOptionCacheMode = 14

< CUDA Only Set cache mode



hipJitOptionSm3xOpt = 15

< @deprecated CUDA Only New SM3X option.



hipJitOptionFastCompile = 16

< CUDA Only Set fast compile



hipJitOptionGlobalSymbolNames = 17

< CUDA Only Array of device symbol names to be relocated to the < host



hipJitOptionGlobalSymbolAddresses = 18

< CUDA Only Array of host addresses to be relocated to the < device



hipJitOptionGlobalSymbolCount = 19

< CUDA Only Number of symbol count.



hipJitOptionLto = 20

< @deprecated CUDA Only Enable link-time optimization for device code



hipJitOptionFtz = 21

< @deprecated CUDA Only Set single-precision denormals.



hipJitOptionPrecDiv = 22

< @deprecated CUDA Only Set single-precision floating-point division < and reciprocals



hipJitOptionPrecSqrt = 23

< @deprecated CUDA Only Set single-precision floating-point square root



hipJitOptionFma = 24

< @deprecated CUDA Only Enable floating-point multiplies and < adds/subtracts operations



hipJitOptionPositionIndependentCode = 25

< CUDA Only Generates Position Independent code



hipJitOptionMinCTAPerSM = 26

< CUDA Only Hints to JIT compiler the minimum number of CTAs frin < kernel’s grid to be mapped to SM



hipJitOptionMaxThreadsPerBlock = 27

< CUDA only Maximum number of threads in a thread block



hipJitOptionOverrideDirectiveValues = 28

< Cuda only Override Directive values



hipJitOptionNumOptions = 29

< Number of options



hipJitOptionIRtoISAOptExt = 10_000

< Hip Only Linker options to be passed on to compiler



hipJitOptionIRtoISAOptCountExt = 10_001

< Hip Only Count of linker options to be passed on to compiler