hiprtcGetErrorString

Function hiprtcGetErrorString 

pub unsafe fn hiprtcGetErrorString(result: hiprtcResult) -> *const c_char
In HIP, this function returns the name of the error, if the hiprtc result is defined, it will return “Invalid HIPRTC error code”