pub unsafe fn hiprtcGetErrorString(result: hiprtcResult) -> *const c_charExpand description
In HIP, this function returns the name of the error, if the hiprtc result is defined, it will return “Invalid HIPRTC error code”
pub unsafe fn hiprtcGetErrorString(result: hiprtcResult) -> *const c_charIn HIP, this function returns the name of the error, if the hiprtc result is defined, it will return “Invalid HIPRTC error code”